@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
-our $DATE = '2017-07-02'; # DATE
-our $VERSION = '0.42'; # VERSION
+our $DATE = '2017-07-03'; # DATE
+our $VERSION = '0.43'; # VERSION
 
 use 5.010001;
 use strict;
@@ -189,7 +189,7 @@ sub _request {
         $resp = $ua->request($req);
         if ($resp->code =~ /^[5]/ && $args{retries} >= ++$tries) {
             log_warn("Got error %s (%s) from server when POST-ing to %s%s, retrying (%d/%d) ...",
-                     $resp->code, $resp->{message},
+                     $resp->code, $resp->message,
                      $url,
                      $args{note} ? " ($args{note})" : "",
                      $tries, $args{retries});
@@ -863,7 +863,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.42 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-07-02.
+This document describes version 0.43 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2017-07-03.
 
 =head1 SYNOPSIS
 
